@@ -20,6 +20,7 @@
 #ifndef __GCAL_UTILS_H__
 #define __GCAL_UTILS_H__
 
+#include "gcal-manager.h"
 #include <gtk/gtk.h>
 #include <libecal/libecal.h>
 #include <libical/icaltime.h>
@@ -101,4 +102,14 @@ gsize           e_utf8_strftime_fix_am_pm                       (gchar
 
 void            fix_popover_menu_icons                          (GtkPopover            *popover);
 
+gboolean        uri_get_fields                                  (const gchar           *uri,
+                                                                 gchar                **schema,
+                                                                 gchar                **host,
+                                                                 gchar                **path);
+
+void            get_source_parent_name_color                    (GcalManager           *manager,
+                                                                 ESource               *source,
+                                                                 gchar                **name,
+                                                                 gchar                **color);
+
 #endif // __GCAL_UTILS_H__
